****************
MetaDataProvider
****************

sqllineage.core.metadata_provider.MetaDataProvider
==================================================

.. autoclass:: sqllineage.core.metadata_provider.MetaDataProvider
    :members:
